@@ -3,11 +3,11 @@
 source ./hack/go-mod-env.sh
 
 REPO=https://github.com/kiegroup/kie-cloud-operator
-BRANCH=$(go run getversion.go -operator)
+VERSION=$(go run getversion.go)
 REGISTRY=quay.io/kiegroup
 IMAGE=kie-cloud-operator
-TAR=${BRANCH}.tar.gz
-URL=${REPO}/archive/${TAR}
+TAR=modules/builder/${IMAGE}.tar.gz
+URL=${REPO}/archive/${VERSION}.tar.gz
 CFLAGS="docker"
 
 if [[ -z ${CI} ]]; then
@@ -16,16 +16,9 @@ fi
 
 ./hack/go-gen.sh
 
-echo
-echo Will build console first:
-echo
-CGO_ENABLED=0 GOOS=linux GOARCH=amd64 go build -v -mod=vendor -a -o build/_output/bin/console-cr-form ./cmd/ui
-echo
-
 if [[ -z ${CI} ]]; then
     echo Now building operator:
     echo
-    operator-sdk build --go-build-args -mod=vendor ${REGISTRY}/${IMAGE}:${BRANCH}
     if [[ ${1} == "rhel" ]]; then
         if [[ ${LOCAL} != true ]]; then
             CFLAGS="osbs"
@@ -34,14 +27,21 @@ if [[ -z ${CI} ]]; then
             fi
         fi
         wget -q ${URL} -O ${TAR}
-        MD5=$(md5sum ${TAR} | awk {'print $1'})
-        rm ${TAR}
-
         echo ${CFLAGS}
-        cekit --redhat build \
-            --overrides "{'artifacts': [{'name': 'kie-cloud-operator.tar.gz', 'md5': '${MD5}', 'url': '${URL}'}]}" \
-            ${CFLAGS}
+        cekit --verbose --redhat build \
+           --overrides '{version: '${VERSION}'}' \
+           ${CFLAGS}
+        rm ${TAR}
+    else
+        echo
+        echo Will build console first:
+        echo
+        CGO_ENABLED=0 GOOS=linux GOARCH=amd64 go build -v -mod=vendor -a -o build/_output/bin/console-cr-form ./cmd/ui
+        echo
+
+        operator-sdk build --go-build-args -mod=vendor ${REGISTRY}/${IMAGE}:${VERSION}
     fi
 else
+    CGO_ENABLED=0 GOOS=linux GOARCH=amd64 go build -v -mod=vendor -a -o build/_output/bin/console-cr-form ./cmd/ui
     CGO_ENABLED=0 GOOS=linux GOARCH=amd64 go build -v -mod=vendor -a -o build/_output/bin/kie-cloud-operator ./cmd/manager
 fi
